import datetime
from flask import current_app
from celery.signals import task_postrun

from .extensions import celery, db

@celery.task(ignore_result=True)
def do_some_stuff():
    current_app.logger.info("I have the application context")
    #you can now use the db object from extensions

@task_postrun.connect
def close_session(*args, **kwargs):
    from extensions import db
    # Flask SQLAlchemy will automatically create new sessions for you from
    # a scoped session factory, given that we are maintaining the same app
    # context, this ensures tasks have a fresh session (e.g. session errors
    # won't propagate across tasks)
    db.session.remove()




# encoding: utf-8
from flask.ext.mail import Message
from ..extensions import mail 



def send_email(subject, sender, recipients, html_body):
    msg = Message(subject, sender=sender, recipients=recipients)
    msg.html = html_body
    mail.send(msg)


#!/usr/bin/env python
# -*- coding: utf-8 -*-
from .. import core
from flask import render_template, request
from flask.ext.login import login_required


@core.route('app')
@login_required
def app():
	return render_template('app.html')



# -*- coding: utf-8 -*-

from flask import Blueprint, render_template, redirect, request, current_app, g, flash, url_for
from flask_login import login_required, logout_user
from flask_babelex import gettext as _
from ..extensions import db


auth = Blueprint('auth', __name__, url_prefix='/auth/', template_folder="templates")



# -*- coding: utf-8 -*-
from os.path import exists
DEBUG = True
SECRET_KEY = 'change me please'
SECURITY_PASSWORD_SALT= 'change me please'

from os.path import dirname, abspath, join
import os
basedir = os.path.abspath(os.path.dirname(__file__))

try:
	import Onyx
	SQLALCHEMY_DATABASE_URI = 'sqlite:///'+str(list(Onyx.__path__)[0]) + "/onyx/data/data.db"
	SQLALCHEMY_MIGRATE_REPO = str(list(Onyx.__path__)[0]) + "/onyx/data/db_repository"
except:
	SQLALCHEMY_DATABASE_URI = 'sqlite:///data/data.db'
	SQLALCHEMY_MIGRATE_REPO = os.path.join(os.path.join('data') , 'db_repository')
SQLALCHEMY_TRACK_MODIFICATIONS = True

# flatpages
FLATPAGES_EXTENSION = '.md'
FLATPAGES_ROOT = join(dirname(__file__), 'docs')
del dirname, abspath, join

# default babel values
BABEL_DEFAULT_LOCALE = 'en'
BABEL_DEFAULT_TIMEZONE = 'UTC'
ACCEPT_LANGUAGES = ['en', 'fr', ]

# available languages
LANGUAGES = {
    'en': u'English',
    'fr': u'Français'
}

MAIL_SERVER= ''
MAIL_PORT=  465
MAIL_USERNAME= ''
MAIL_PASSWORD= ''
MAIL_USE_TLS= False
MAIL_USE_SSL= True
# Celery
BROKER_TRANSPORT = 'redis'
CELERY_BROKER_URL = 'redis://localhost:6379/0'
CELERY_RESULT_BACKEND = 'redis://localhost:6379/0'
CELERY_TASK_SERIALIZER = 'json'
CELERY_DISABLE_RATE_LIMITS = True
CELERY_ACCEPT_CONTENT = ['json',]

# cache
CACHE_TYPE = 'memcached'
CACHE_MEMCACHED_SERVERS = ['127.0.0.1:11211', ]
# CACHE_MEMCACHED_USERNAME =
# CACHE_MEMCACHED_PASSWORD =



# -*- coding: utf-8 -*-
#pylint:disable-msg=W0612

import os
from flask import Flask, request, render_template , g , abort , redirect , url_for
from celery import Celery

from .extensions import (db, mail, pages, manager, login_manager, babel, csrf, cache, celery)
from flask_login import current_user
import os.path
from os.path import dirname, abspath, join
import json
from flask.ext.babelex import gettext , lazy_gettext



# blueprints
try:
    from .install import install
    BLUEPRINTS = install
    blueprint_name = 'install'
except:
    from .controllers import core
    from .auth import auth
    from .api import api_v1
    BLUEPRINTS = [core,auth,api_v1]
    blueprint_name = 'core'

__all__ = ('create_app', 'create_celery', )




def create_app(config=None, app_name='onyx', blueprints=None):
    app = Flask(app_name,
        static_folder=os.path.join(os.path.dirname(__file__), '..', 'static'),
        template_folder= 'templates'
    )    
    try:
        app.config.from_object('Onyx.onyx.config')
    except:
        app.config.from_object('onyx.config')
    app.config.from_pyfile('../local.cfg', silent=True)
    if config:
        app.config.from_pyfile(config)

    if blueprints is None:
        blueprints = BLUEPRINTS

    blueprints_fabrics(app, blueprints)
    extensions_fabrics(app)

    error_pages(app , blueprint_name)
    gvars(app)

    with app.app_context():
        from migrate.versioning import api
        db.create_all()
        try:
            if not os.path.exists(app.config['SQLALCHEMY_MIGRATE_REPO']):
                api.create(app.config['SQLALCHEMY_MIGRATE_REPO'], 'database repository')
                api.version_control(app.config['SQLALCHEMY_DATABASE_URI'],app.config['SQLALCHEMY_MIGRATE_REPO'])
            else:
                api.version_control(app.config['SQLALCHEMY_DATABASE_URI'], app.config['SQLALCHEMY_MIGRATE_REPO'],
                                    api.version(app.config['SQLALCHEMY_MIGRATE_REPO']))
        except:
            print("Migrate Already Done")
        print ("Base de donnée initialisée")
  
    return app


def create_celery(app):
    celery = Celery(app.import_name, broker=app.config['CELERY_BROKER_URL'])
    celery.conf.update(app.config)
    TaskBase = celery.Task
    class ContextTask(TaskBase):
        abstract = True
        def __call__(self, *args, **kwargs):
            with app.app_context():
                return TaskBase.__call__(self, *args, **kwargs)
    celery.Task = ContextTask
    return celery

def blueprints_fabrics(app, blueprints):
    """Configure blueprints in views."""
    try:
        for blueprint in blueprints:
            app.register_blueprint(blueprint)
    except:
        app.register_blueprint(blueprints)


def extensions_fabrics(app):
    db.init_app(app)
    mail.init_app(app)
    babel.init_app(app)
    pages.init_app(app)
    login_manager.init_app(app)
    cache.init_app(app)
    celery.config_from_object(app.config)

def gvars(app):


    @app.before_request
    def gvariables():
        g.user = current_user
        g.gapi = app.config.get('GAPI')
        g.gcx = app.config.get('GCX')
        g.action = { gettext('Quel temps fait il ?'): { "id" : "0" , "type" : "url" , "url" : "weather" }, gettext('Weather'): { "id" : "1" , "type" : "url" , "url" : "weather" } }
                

    @app.context_processor
    def inject_user():
        try:
            return {'user': g.user}
        except AttributeError:
            return {'user': None}

    @app.teardown_request
    def teardown_request(exception):
        if exception:
            db.session.rollback()
            db.session.remove()
        db.session.remove()



    @babel.localeselector
    def get_locale():
        if g.user:
            if hasattr(g.user, 'lang'):
                return g.user.lang
        accept_languages = app.config.get('ACCEPT_LANGUAGES')
        return request.accept_languages.best_match(accept_languages)


def error_pages(app , name):
    # HTTP error pages definitions

    @app.errorhandler(403)
    def forbidden_page(error):
        return render_template("404.html", blueprint=name), 403

    @app.errorhandler(404)
    def page_not_found(error):
        return render_template("404.html" , blueprint=name), 404

    @app.errorhandler(405)
    def method_not_allowed(error):
        return render_template("404.html", blueprint=name), 404

    @app.errorhandler(500)
    def server_error_page(error):
        return render_template("404html", blueprint=name), 500





#!/usr/bin/env python
# -*- coding: utf-8 -*-
from .. import core
from ...extensions import db
from flask import render_template , redirect , url_for , flash , request
from flask.ext.login import login_required , current_user
from flask.ext.babelex import gettext
from ...models import *
from ...extensions import db
import platform
import os

@core.route('options' , methods=['GET','POST'])
@login_required
def options():
	if request.method == 'GET':
		return render_template('options/index.html')
	user = UsersModel.User.query.filter_by(username=current_user.username).first()
	user.lang = request.form['lang']
	db.session.add(user)
	db.session.commit()
	flash(gettext('Account changed successfully' ), 'success')
	return redirect(url_for('core.options'))

@core.route('maj')
@login_required
def maj():
	from ...config import SQLALCHEMY_DATABASE_URI
	from ...config import SQLALCHEMY_MIGRATE_REPO
	import imp
	from migrate.versioning import api
	v = api.db_version(SQLALCHEMY_DATABASE_URI, SQLALCHEMY_MIGRATE_REPO)
	migration = SQLALCHEMY_MIGRATE_REPO + ('/versions/%03d_migration.py' % (v+1))
	tmp_module = imp.new_module('old_model')
	old_model = api.create_model(SQLALCHEMY_DATABASE_URI, SQLALCHEMY_MIGRATE_REPO)
	exec(old_model, tmp_module.__dict__)
	script = api.make_update_script_for_model(SQLALCHEMY_DATABASE_URI,SQLALCHEMY_MIGRATE_REPO,tmp_module.meta, db.metadata)
	open(migration, "wt").write(script)
	api.upgrade(SQLALCHEMY_DATABASE_URI, SQLALCHEMY_MIGRATE_REPO)
	v = api.db_version(SQLALCHEMY_DATABASE_URI, SQLALCHEMY_MIGRATE_REPO)
	print('New migration saved as ' + migration)
	print('Current database version: ' + str(v))
	flash(gettext("Onyx is now upgrade !"),'success')
	return redirect(url_for('core.options'))


#!/usr/bin/env python
# -*- coding: utf-8 -*-
from .. import core
from flask import redirect , url_for , request , g , jsonify , flash
from flask.ext.login import login_required
import json
from flask.ext.babelex import gettext , lazy_gettext

@core.route('action/get/' , methods=['GET','POST'])
@login_required
def action():
	if request.method == 'POST':
		try:
			action = request.form['action']
			data = json.dumps(g.action)
			load = json.loads(data)
			url = load[action]['url']
			return redirect(url_for("core."+url))
		except:
			flash(gettext('An error has occurred !') , "error")
			return redirect(url_for("core.index"))

	flash(gettext('An error has occurred !') , "error")
	return redirect(url_for("core.index"))



from flask_restplus import Namespace, Resource, fields

api = Namespace('tasks', description='Tasks')

calendar = api.model('Calendar', {
    'id': fields.String(required=True, description='The Event Identifier'),
    'name': fields.String(required=True, description='The Event Name'),
    'date': fields.String(required=True, description='The Event Date'),
})

EVENTS = [
    {'id': '1', 'name': 'Manger' , 'date':'3 Juillet'},
]


@api.route('/')
class CalendarList(Resource):
    @api.doc('list_event')
    @api.marshal_list_with(calendar)
    def get(self):
        '''List all event'''
        return EVENTS


@api.route('/<id>')
@api.param('id', 'The Event Identifier')
@api.response(404, 'Event not found')
class Dog(Resource):
    @api.doc('get_event')
    @api.marshal_with(calendar)
    def get(self, id):
        '''Fetch a event given its identifier'''
        for event in EVENTS:
            if event['id'] == id:
                return event
        api.abort(404)



# -*- coding: utf-8 -*-

from flask import Blueprint, render_template, redirect, request, current_app, g, flash, url_for
from flask.ext.login import LoginManager , login_user , login_required , current_user , login_user , logout_user
from flask_babel import gettext as _
from ..extensions import db , login_manager
from ..models import *
import os
import site
import hashlib
import os.path
import datetime



install = Blueprint('install', __name__, url_prefix='/install', template_folder=os.path.dirname(os.path.dirname(__file__)) + '/templates')


@login_manager.user_loader
def load_user(id):
    return UsersModel.User.query.get(int(id))


@install.route('/' , methods=['GET','POST'])
def index():
	if request.method == 'GET':
		return render_template('install/index.html')
	db.session.rollback()
	hashpass = hashlib.sha1(request.form['password'].encode('utf-8')).hexdigest()
	user = UsersModel.User(admin=1 ,confirmed_on=datetime.datetime.now(),registered_on=datetime.datetime.now(),confirmed=True, username=request.form['username'] , password=hashpass, email=request.form['email'])
	db.session.add(user)
	db.session.commit()
	login_user(user)
	try:
		os.rename(os.path.dirname(os.path.dirname(__file__)) + '/install', os.path.dirname(os.path.dirname(__file__)) + '/installOld')
	except:
		import Onyx
		os.rename(str(Onyx.__path__[0]) + "/onyx/install" , str(Onyx.__path__[0]) + "/onyx/installOld")
	flash('Onyx a bien été installé !' , 'success')
	return redirect(url_for("install.finish"))


@install.route('/finish' , methods=['GET','POST'])
@login_required
def finish():
	return render_template('install/finish.html')



# -*- coding: utf-8 -*-


from flask_mail import Mail
mail = Mail()

from flask_sqlalchemy import SQLAlchemy
db = SQLAlchemy()

from flask_flatpages import FlatPages
pages = FlatPages()

import flask_restless
manager = flask_restless.APIManager()

from flask_login import LoginManager
login_manager = LoginManager()
try:
	login_manager.login_view = 'core.hello'
except:
	login_manager.login_view = 'install.installer'

import Onyx
from flask_babelex import Babel , Domain
domain = Domain(domain=str(Onyx.__path__[0]) + "/onyx/translations")
babel = Babel()

from flask_migrate import Migrate
migrate = Migrate()

from flask_wtf.csrf import CsrfProtect
csrf = CsrfProtect()

from flask_cache import Cache
cache = Cache()

from celery import Celery
celery = Celery()





#!/usr/bin/env python
# -*- coding: utf-8 -*-
from flask import render_template, request , redirect , url_for
from .. import core
import os

@core.route('info')
def info():
    return render_template('info.html')


# -*- coding: utf-8 -*-

from flask import Blueprint, render_template, redirect, request, current_app, g, flash, url_for
from flask_login import login_required, logout_user
from flask_babelex import gettext as _
import os



core = Blueprint('core', __name__, url_prefix='/' , template_folder=os.path.dirname(os.path.dirname(__file__)) + '/templates')

from .views import *




#!/usr/bin/env python
# -*- coding: utf-8 -*-

import Onyx
import os

try:
	os.rename(str(Onyx.__path__[0]) + "/onyx/config_example.py" , str(Onyx.__path__[0]) + "/onyx/config.py")
	print('Config File Create')
except:
	print('Config File Already Create')


from .onyx import create_app
from .onyx.extensions import db

def runserver():
	app = create_app()
	app.run(debug=True)


#!/usr/bin/env python
# -*- coding: utf-8 -*-

from flask import json

from flask_script import Manager , Server
from flask_migrate import MigrateCommand
try:
    from Onyx import create_app
    from Onyx.extensions import db
except:
    from .onyx import create_app
    from .onyx.extensions import db

manager = Manager(create_app)


def runserver():
	app = create_app()
	app.run(debug=True)
    #manager.run()


if __name__ == "__main__":
    manager.run()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from flask import render_template, request , redirect , url_for
from flask.ext.login import login_required
from .. import core
import os

@core.route('translate')
@login_required
def translate():
	return render_template('translate/index.html')



# -*- coding: utf-8 -*-

from flask import Blueprint, render_template, current_app


from flask_restplus import Api

from .controllers import *

apikey = "dada"

api_v1 = Blueprint('api', __name__, url_prefix='/api/v1')

api = Api(version='1.0',title="Onyx API",description="Onyx Api version 1.0",)
api.init_app(api_v1)
api.add_namespace(calendar.api)
api.add_namespace(users.api)
api.add_namespace(tasks.api)







import sys

from setuptools import setup , find_packages


setup(name="onyxproject",
      description="Intelligent Dashboard",
      version='0.2.6',
      packages=['Onyx'],
      include_package_data=True,
      url="https://gitlab.com/Aituglo/Onyx",
      maintainer=("Aituglo"),
      maintainer_email="project@onyxlabs.fr",
      classifiers=[
          "Development Status :: 5 - Production/Stable",
          "Environment :: Web Environment",
          "Intended Audience :: Developers",
          "Intended Audience :: System Administrators",
          "Operating System :: OS Independent",
          "Programming Language :: Python :: 3.5",
          "Topic :: Software Development :: Build Tools",
          "Topic :: System :: Software Distribution"],
      zip_safe=True,
      entry_points={
          'console_scripts': ['onyxstart=Onyx:runserver']
      },
      install_requires=['pip','Babel' , 'Flask-Babel' , 'Flask-Script' , 'Flask-FlatPages' , 'Markdown' , 'PyYAML' , 'Werkzeug' , 'flask-migrate' ,'itsdangerous' , 'speaklater' , 'Flask-Cache' , 'pylibmc' , 'redis' , 'celery' , 'flask-restless' ,'Flask==0.10.1','Flask-WTF','Flask-sqlalchemy','requests','beautifulsoup4','Flask-Menu','Flask-Login','SQLAlchemy-migrate','flask_bcrypt','flask-Mail','blinker','wikipedia','markupsafe'],
      options={
          'bdist_wheel': {'universal': True},
      },
      platforms=['any'],
      )



from flask import request, redirect , url_for
from functools import wraps


def require_appkey(view_function):
	@wraps(view_function)
	def decorated_function(*args, **kwargs):
		if request.args.get('key') and request.args.get('key') == 'APPKEY_HERE':
			return view_function(*args, **kwargs)
		else:
			return redirect(url_for('core.index'))
		return decorated_function



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from .. import core
from flask.ext.login import LoginManager , login_user , login_required , current_user , login_user , logout_user
from flask import request , render_template , redirect , url_for , flash , session
from flask.ext.babelex import gettext
from flask.ext.mail import Message
from ...models import *
from ...extensions import db , mail , login_manager
from ...config import SECRET_KEY
from ...config import SECURITY_PASSWORD_SALT
from os.path import exists
import hashlib
import datetime
from itsdangerous import URLSafeTimedSerializer
import os




def generate_confirmation_token(email):
    serializer = URLSafeTimedSerializer(SECRET_KEY)
    return serializer.dumps(email, salt=SECURITY_PASSWORD_SALT)


def confirm_token(token, expiration=3600):
    serializer = URLSafeTimedSerializer(SECRET_KEY)
    try:
        email = serializer.loads(
            token,
            salt=SECURITY_PASSWORD_SALT,
            max_age=expiration
        )
    except:
        return False
    return email



def send_mail(recipient , title , message):
    msg = Message(title, sender = 'Onyx', recipients = [recipient])
    msg.html = message
    mail.send(msg)

@login_manager.user_loader
def load_user(id):
    return UsersModel.User.query.get(int(id))

@core.route('register' , methods=['GET','POST'])
def register():
    if request.method == 'GET':
        return render_template('account/register.html')
    try:
        if request.form['password'] == request.form['verifpassword']:
            hashpass = hashlib.sha1(request.form['password'].encode('utf-8')).hexdigest()
            user = UsersModel.User(admin=0 ,confirmed_on=datetime.datetime.now(),registered_on=datetime.datetime.now(),confirmed=False, username=request.form['username'] , password=hashpass, email=request.form['email'])
            db.session.add(user)
            db.session.commit()
            token = generate_confirmation_token(request.form['email'])
            confirm_url = url_for('core.confirm_email', token=token, _external=True)
            html = render_template('account/activate.html', confirm_url=confirm_url)
            subject = "Confirmer votre compte Onyx"
            send_mail(request.form['email'], subject, html)
            login_user(user)
            flash(gettext('A mail will be send to your mail address'), 'success')
            return redirect(url_for('core.unconfirmed'))        
        else:
            flash(gettext('Passwords are not same !' ), 'error')
            return redirect(url_for('core.register'))
    except:
        flash(gettext('You name or password are already used !' ), 'error')
        return redirect(url_for('core.hello'))

@core.route('register/resetpassword' , methods=['GET','POST'])
def resetpassword():
    if request.method == 'GET':
        return render_template('account/reset.html' , mail=True)
    try:
        token = generate_confirmation_token(request.form['email'])
        confirm_url = url_for('core.confirm_reset', token=token, _external=True)
        html = render_template('account/resetMail.html', confirm_url=confirm_url)
        subject = "Changer votre mot de passe Onyx"
        send_mail(request.form['email'], subject, html)
        flash(gettext('A mail will be send to your mail address'), 'success')
        return redirect(url_for('core.resetpassword'))
    except:
        flash(gettext("We don't know your mail" ), 'error')
        return redirect(url_for('core.resetpassword'))


@core.route('register/confirm/<token>')
def confirm_email(token):
    try:
        email = confirm_token(token)
    except:
        flash(gettext('The link is invalid or expire'), 'error')
    user = UsersModel.User.query.filter_by(email=email).first_or_404()
    if user.confirmed:
        flash(gettext('You can now connect'), 'success')
    else:
        user.confirmed = True
        user.confirmed_on = datetime.datetime.now()
        db.session.add(user)
        db.session.commit()
        login_user(user)
        flash(gettext('Your account is active now'), 'success')
    return redirect(url_for('core.index'))


@core.route('register/resetpassword/confirm/<token>', methods=['GET','POST'])
def confirm_reset(token):
    if request.method == 'GET':
        try:
            email = confirm_token(token)
        except:
            flash(gettext('The link is invalid or expire'), 'error')
        user = UsersModel.User.query.filter_by(email=email).first_or_404()
        return render_template('account/resetPassword.html')
    try:
        email = confirm_token(token)
        user = UsersModel.User.query.filter_by(email=email).first()
        user.password = hashlib.sha1(request.form['password']).hexdigest()
        db.session.add(user)
        db.session.commit()
        flash(gettext('Password changed !' ), 'success')
        return redirect(url_for('core.hello'))
    except:
        flash(gettext('An error has occurred !') , 'error')
        return redirect(url_for('core.hello'))



@core.route('unconfirmed')
def unconfirmed():
    flash(gettext('Please confirm your account !'), 'error')
    return render_template('account/unconfirmed.html')

@core.route('resend' , methods=['GET' , 'POST'])
def resend_confirmation():
    if request.method == 'GET':
        return render_template('account/resend.html')
    try:
        token = generate_confirmation_token(request.form['email'])
        confirm_url = url_for('core.confirm_email', token=token, _external=True)
        html = render_template('account/activate.html', confirm_url=confirm_url)
        subject = "Veuillez confirmer votre adresse mail !"
        send_mail(request.form['email'], subject, html)
        flash(gettext('A new mail will be send !'), 'success')
        return redirect(url_for('core.unconfirmed'))
    except:
        flash(gettext("You can't watch it !"), 'success')
        return redirect(url_for('core.index'))



@core.route('hello')
def hello():
    return render_template('account/hello.html')
 

@core.route('login',methods=['GET','POST'])
def login():
    if request.method == 'GET':
        return render_template('account/login.html')
    try:
        email = request.form['email']
        password = request.form['password'].encode('utf-8')
        registered_user = UsersModel.User.query.filter_by(email=email,password=hashlib.sha1(password).hexdigest()).first()
        if registered_user is None:
            flash(gettext('Incorrect email or password !'), 'error')
            return redirect(url_for('core.login'))
        if registered_user.confirmed:
            login_user(registered_user)
            registered_user.authenticated = True
            flash(gettext('You are now connected'), 'success')
            return redirect(request.args.get('next') or url_for('core.index'))
        else:
            return redirect(url_for('core.unconfirmed'))
    except:
        flash(gettext('An error has occurred !'), 'error')
        return redirect(url_for('core.login'))


@core.route('account/delete' , methods=['GET','POST'])
@login_required
def accountdel():
    if request.method == 'GET':
        try:
            bdd = UsersModel.User.query.all()
            resultUsername = []
            for myusers in bdd:
                resultUsername.append(myusers.username) 
            resultUser = resultUsername

            resultEmailRow = []
            for myusers in bdd:
                resultEmailRow.append(myusers.email) 
            resultEmail = resultEmailRow

            resultIdRow = []
            for myusers in bdd:
                resultIdRow.append(myusers.id) 
            resultId = resultIdRow


            return render_template('account/delete.html' , username=resultUser , email=resultEmail , id=resultId )
        except:
            return render_template('account/delete.html' , error="Pas de comptes")


@core.route('account/delete/<id_delete>')
def delete_account(id_delete):
    try:
        delete = UsersModel.User.query.filter_by(id=id_delete).first()
        db.session.delete(delete)
        db.session.commit()
        deleteCalendar = CalendarModel.Calendar.query.filter(CalendarModel.Calendar.idAccount.endswith(str(id_delete)))
        for fetch in deleteCalendar:
            deleteEvent = CalendarModel.Calendar.query.filter_by(id=fetch.id).first()
            db.session.delete(deleteEvent)
            db.session.commit()
        deleteTask = TaskModel.Task.query.filter(TaskModel.Task.idAccount.endswith(str(id_delete)))
        for fetch in deleteTask:
            deleteEventTask = TaskModel.Task.query.filter_by(id=fetch.id).first()
            db.session.delete(deleteEventTask)
            db.session.commit()
        flash(gettext('Account deleted !') , 'success')
        return redirect(url_for('core.accountdel'))
    except:
        flash(gettext('An error has occurred !') , 'error')
        return redirect(url_for('core.accountdel'))


@core.route('account/manage' , methods=['GET','POST'])
@login_required
def accountManage():
    if request.method == 'GET':
        bdd = UsersModel.User.query.filter_by(username=current_user.username).first()
        buttonColor = bdd.buttonColor
        return render_template('account/manage.html' ,buttonColor=buttonColor )
    try:
        user = UsersModel.User.query.filter_by(username=current_user.username).first()
        lastpassword = user.password
        if hashlib.sha1(request.form['lastpassword'].encode('utf-8')).hexdigest() == lastpassword:
            if not request.form['username']:
                user.username = current_user.username
            else:
                user.username = request.form['username']
            if not request.form['email']:
                user.email = current_user.email
            else:
                user.email = request.form['email']
            if not request.form['password']:
                user.password = current_user.password
            else:
                user.password = hashlib.sha1(request.form['password'].encode('utf-8')).hexdigest()
            db.session.add(user)
            db.session.commit()
            flash(gettext('Account changed successfully' ), 'success')
            return redirect(url_for('core.accountManage'))
        else:
            flash(gettext('Passwords are not same !' ), 'error')
            return redirect(url_for('core.accountManage'))
    except:
        flash(gettext('Another user use data') , 'error')
        return redirect(url_for('core.accountManage'))

@core.route('account/manage/color' , methods=['GET','POST'])
@login_required
def changeColor():
    if request.method == 'GET':
        bdd = UsersModel.User.query.filter_by(username=current_user.username).first()
        buttonColor = bdd.buttonColor
        return render_template('account/color.html' ,buttonColor=buttonColor )
    try:
        user = UsersModel.User.query.filter_by(username=current_user.username).first()
        if not request.form['color']:
            user.buttonColor = current_user.buttonColor
        else:
            user.buttonColor = request.form['color']
        db.session.add(user)
        db.session.commit()
        flash(gettext('Account changed successfully') , 'success')
        return redirect(url_for('core.accountManage'))
    except:
        return redirect(url_for('core.accountManage'))



@core.route('logout' , methods=['GET','POST'])
def logout():
    login_manager.login_view = 'core.hello'
    logout_user()
    flash(gettext('You are now log out' ), 'info')
    return redirect(url_for('core.hello'))